@@ -30,7 +30,7 @@
 //these are all constants defined only for reporting versioning.  They are returned by Module('Version')
 #define PSYCHTOOLBOX_MAJOR_VERSION              3
 #define PSYCHTOOLBOX_MINOR_VERSION              0
-#define PSYCHTOOLBOX_POINT_VERSION              11
+#define PSYCHTOOLBOX_POINT_VERSION              12
 //If you fork my source please change this name.  - awi 
 #define PSYCHTOOLBOX_PROJECT_NAME               "OpenGL Psychtoolbox"
 #if PSYCH_SYSTEM == PSYCH_OSX
@@ -43,12 +43,16 @@
 #endif
 #if PSYCH_SYSTEM == PSYCH_LINUX
 //Placeholder for the GNU/Linux version at build time.
+#ifdef PTB_USE_WAYLAND
+#define PSYCHTOOLBOX_OS_NAME                                    "GNU/Linux WAYLAND"
+#else
 #ifdef PTB_USE_WAFFLE
 #define PSYCHTOOLBOX_OS_NAME                                    "GNU/Linux WAFFLE"
 #else
 #define PSYCHTOOLBOX_OS_NAME                                    "GNU/Linux X11"
 #endif
 #endif
+#endif
 
 #if defined(__LP64__) || defined(_WIN64)
 #define PTB_ARCHITECTURE " 64-Bit"
@@ -62,7 +66,7 @@
 #define PSYCHTOOLBOX_SCRIPTING_LANGUAGE_NAME	                "Matlab" PTB_ARCHITECTURE
 #else
 // Binary plugin for Octave-3 or later via the MEX interface:
-#define PSYCHTOOLBOX_SCRIPTING_LANGUAGE_NAME	                "GNU/Octave-3" PTB_ARCHITECTURE
+#define PSYCHTOOLBOX_SCRIPTING_LANGUAGE_NAME	                "GNU/Octave" PTB_ARCHITECTURE
 #endif
 #endif
 
