@@ -330,9 +330,6 @@ PsychError SCREENFlip(void)
 		flipRequest->vbl_timestamp = -1;
 		
 		// Ok, the struct is filled with spec for a synchronous or asynchronous flip...
-		
-		// Store current preflip GPU graphics surface addresses, if supported:
-		PsychStoreGPUSurfaceAddresses(windowRecord);
 	}
 	else {
 		// opmode == 2 or 3 - 'AsyncFlipEnd' or 'AsyncFlipCheckEnd':
@@ -444,7 +441,6 @@ PsychError SCREENWaitUntilAsyncFlipCertain(void)
 	double vbl_startline, vbl_endline, vbl_lines_elapsed, onset_lines_togo;
 	double vbl_time_elapsed, onset_time_togo, currentrefreshestimate;
 	psych_bool   swappending;
-	long   scw, sch;
 #endif
 
 	// Push usage string and/or give online help:
@@ -515,8 +511,7 @@ PsychError SCREENWaitUntilAsyncFlipCertain(void)
 		PsychCopyOutDoubleArg(3, kPsychArgOptional, timestamp);
 		
 		// Compute timestamps:
-		PsychGetScreenSize(windowRecord->screenNumber, &scw, &sch);
-		vbl_startline = (int) sch;
+		vbl_startline = windowRecord->VBL_Startline;
 		vbl_endline = windowRecord->VBL_Endline;
 		
 		if (swappending) {
