@@ -101,8 +101,8 @@ void InitializeSynopsis()
     synopsis[i++] = "\n% New OpenGL functions for OS X:";
     synopsis[i++] = "Screen('glPoint', windowPtr, color, x, y [,size]);";
     synopsis[i++] = "Screen('gluDisk', windowPtr, color, x, y [,size]);";
-    synopsis[i++] = "Screen('DrawDots', windowPtr, xy [,size] [,color] [,center] [,dot_type]);";
-    synopsis[i++] = "Screen('DrawLines', windowPtr, xy [,width] [,colors] [,center] [,smooth]);";
+    synopsis[i++] = "[minSmoothPointSize, maxSmoothPointSize, minAliasedPointSize, maxAliasedPointSize] = Screen('DrawDots', windowPtr, xy [,size] [,color] [,center] [,dot_type] [,lenient]);";
+    synopsis[i++] = "[minSmoothLineWidth, maxSmoothLineWidth, minAliasedLineWidth, maxAliasedLineWidth] = Screen('DrawLines', windowPtr, xy [,width] [,colors] [,center] [,smooth] [,lenient]);";
     synopsis[i++] = "[sourceFactorOld, destinationFactorOld, colorMaskOld]=Screen('BlendFunction', windowIndex, [sourceFactorNew], [destinationFactorNew], [colorMaskNew]);";
 
     // Draw Text in windows
@@ -143,7 +143,7 @@ void InitializeSynopsis()
     // Load color lookup table of the window's screen (on-screen only)
     synopsis[i++] = "\n% Load color lookup table of the window's screen (on-screen only):";
     synopsis[i++] = "[gammatable, dacbits, reallutsize] = Screen('ReadNormalizedGammaTable', windowPtrOrScreenNumber [, physicalDisplay]);";
-    synopsis[i++] = "Screen('LoadNormalizedGammaTable', windowPtrOrScreenNumber, table [, loadOnNextFlip] [, physicalDisplay]);";
+    synopsis[i++] = "[oldtable, success] = Screen('LoadNormalizedGammaTable', windowPtrOrScreenNumber, table [, loadOnNextFlip][, physicalDisplay][, ignoreErrors]);";
     synopsis[i++] = "oldclut = Screen('LoadCLUT', windowPtrOrScreenNumber [, clut] [, startEntry=0] [, bits=8]);";
 
     // Get and set information about a window or screen.
@@ -189,7 +189,7 @@ void InitializeSynopsis()
     synopsis[i++] ="[x, y, buttonVector, hasKbFocus, valuators]= Screen('GetMouseHelper', numButtons [, screenNumber][, mouseIndex]);";
     synopsis[i++] = "Screen('HideCursorHelper', windowPntr [, mouseIndex]);";
     synopsis[i++] = "Screen('ShowCursorHelper', windowPntr [, cursorshapeid][, mouseIndex]);";
-    synopsis[i++] = "Screen('SetMouseHelper', windowPntrOrScreenNumber, x, y [, mouseIndex]);";
+    synopsis[i++] = "Screen('SetMouseHelper', windowPntrOrScreenNumber, x, y [, mouseIndex][, detachFromMouse]);";
 
     // Internal testing of Screen
     synopsis[i++] = "\n% Internal testing of Screen";
