@@ -548,6 +548,7 @@ void  PsychAssignParentWindow(PsychWindowRecordType *childWin, PsychWindowRecord
 	
 	// Copy color range and mode from parent window:
 	childWin->colorRange = parentWin->colorRange;
+	childWin->applyColorRangeToDoubleInputMakeTexture = parentWin->applyColorRangeToDoubleInputMakeTexture;
 
 	// Copy imaging mode flags from parent:
 	childWin->imagingMode = parentWin->imagingMode;
@@ -555,7 +556,11 @@ void  PsychAssignParentWindow(PsychWindowRecordType *childWin, PsychWindowRecord
 	// Inherit capability bits of parents context:
 	childWin->gfxcaps = parentWin->gfxcaps;
 	childWin->maxTextureSize = parentWin->maxTextureSize;
-	
+
+    // Type of display backend and graphics api:
+    childWin->glApiType = parentWin->glApiType;
+    childWin->winsysType = parentWin->winsysType;
+
 	return;
 }
 
