@@ -8,13 +8,13 @@ function datapixxmakemex()
         if Is64Bit
           VPIXXDIR = '/home/kleinerm/projects/';
         else
-          VPIXXDIR = '/media/sf_kleinerm/projects/';        
+          VPIXXDIR = '/media/sf_kleinerm/projects/';
         end
-        
+
         CPYCMD = 'cp ';
         DELCMD = 'rm ';
     elseif (IsWin)
-        VPIXXDIR = 'T:/projects/';        
+        VPIXXDIR = 'T:/projects/';
         CPYCMD = 'copy ';
         DELCMD = 'del ';
     end
@@ -78,7 +78,7 @@ function datapixxmakemex()
         S = [S ' ' VPIXXDIR 'VPixx_Software_Tools/libusb/usb.c'];
         S = [S ' ' VPIXXDIR 'VPixx_Software_Tools/libusb/darwin.c'];
         S = [S ' ' PTBDIR 'PsychSourceGL/Source/OSX/Base/PsychTimeGlue.c'];
-        S = [S ' "-Wl,-headerpad_max_install_names -F/System/Library/Frameworks/ -F/Library/Frameworks/ -framework ApplicationServices -framework CoreServices -framework CoreFoundation -framework Carbon -framework CoreAudio -framework IOKit,-syslibroot,''/Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.9.sdk'' -mmacosx-version-min=''10.8'' "'];
+        S = [S ' "-Wl,-headerpad_max_install_names -F/System/Library/Frameworks/ -F/Library/Frameworks/ -framework ApplicationServices -framework CoreServices -framework CoreFoundation -framework Carbon -framework CoreAudio -framework IOKit,-syslibroot,''/Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.11.sdk'' -mmacosx-version-min=''10.8'' "'];
         if (IsOctave)
             S = [S ' --output ' VPIXXDIR 'VPixx_Software_Tools/DatapixxToolbox_trunk/mexdev/build/octave/macosx/Datapixx.mex'];
         else
@@ -114,7 +114,12 @@ function datapixxmakemex()
         if (Is64Bit)
             S = [S ' -L' VPIXXDIR 'VPixx_Software_Tools/libusb_win32/libusb-win32-device-bin-0.1.12.2/lib/msvc_x64 -llibusb'];
         else
-            S = [S ' -L' VPIXXDIR 'VPixx_Software_Tools/libusb_win32/libusb-win32-device-bin-0.1.12.2/lib/msvc -llibusb'];
+            if IsOctave
+                %S = [S ' -L' VPIXXDIR 'VPixx_Software_Tools/libusb_win32/libusb-win32-device-bin-0.1.12.2/lib/gcc libusb.a'];
+                S = [S ' ' VPIXXDIR 'VPixx_Software_Tools/libusb_win32/libusb-win32-device-bin-0.1.12.2/lib/gcc/libusb.a'];
+            else
+                S = [S ' -L' VPIXXDIR 'VPixx_Software_Tools/libusb_win32/libusb-win32-device-bin-0.1.12.2/lib/msvc -llibusb'];
+            end
         end
         if (IsOctave)
             S = [S ' -lWinmm']; % for timeGetTime() et al
@@ -131,9 +136,9 @@ function datapixxmakemex()
 
     eval(strrep(S, '/', filesep));
 
-%   Move mex file to final destination, and clean up any temporary build files.
-%   Octave puts object files in same folders as source files, and we have to delete them manually.
-%   Matlab is a bit smarter, putting the object files in the current directory, then immediately cleaning them up.
+    %   Move mex file to final destination, and clean up any temporary build files.
+    %   Octave puts object files in same folders as source files, and we have to delete them manually.
+    %   Matlab is a bit smarter, putting the object files in the current directory, then immediately cleaning them up.
     if (IsOctave)
         system(strrep([DELCMD VPIXXDIR 'VPixx_Software_Tools/DatapixxToolbox_trunk/mexdev/src/*.o'], '/', filesep));
         system(strrep([DELCMD VPIXXDIR 'VPixx_Software_Tools/libdpx/src/*.o'], '/', filesep));
@@ -143,17 +148,22 @@ function datapixxmakemex()
             system(strrep([DELCMD VPIXXDIR 'VPixx_Software_Tools/libusb/*.o'], '/', filesep));
             system(strrep([DELCMD PTBDIR 'PsychSourceGL/Source/OSX/Base/*.o'], '/', filesep));
             system(strrep([CPYCMD VPIXXDIR 'VPixx_Software_Tools/DatapixxToolbox_trunk/mexdev/build/octave/macosx/Datapixx.mex ' PTBDIR 'Psychtoolbox/PsychBasic/Octave3OSXFiles64'], '/', filesep));
+            osxsetoctaverpath('Datapixx', [PTBDIR 'Psychtoolbox/PsychBasic/Octave3OSXFiles64/']);
+            system(strrep([CPYCMD VPIXXDIR 'VPixx_Software_Tools/DatapixxToolbox_trunk/mexdev/build/octave/macosx/Datapixx.mex ' PTBDIR 'Psychtoolbox/PsychBasic/Octave4OSXFiles64'], '/', filesep));
+            osxsetoctaverpath4('Datapixx', [PTBDIR 'Psychtoolbox/PsychBasic/Octave4OSXFiles64/']);
         elseif (IsLinux)
             system(strrep([DELCMD VPIXXDIR 'VPixx_Software_Tools/libusb/*.o'], '/', filesep));
             system(strrep([DELCMD PTBDIR 'PsychSourceGL/Source/Linux/Base/*.o'], '/', filesep));
             if (Is64Bit)
                 system(strrep([CPYCMD VPIXXDIR 'VPixx_Software_Tools/DatapixxToolbox_trunk/mexdev/build/octave/linux64/Datapixx.mex ' PTBDIR 'Psychtoolbox/PsychBasic/Octave3LinuxFiles64'], '/', filesep));
+                striplibsfrommexfile([PTBDIR 'Psychtoolbox/PsychBasic/Octave3LinuxFiles64/Datapixx.mex']);
             else
                 system(strrep([CPYCMD VPIXXDIR 'VPixx_Software_Tools/DatapixxToolbox_trunk/mexdev/build/octave/linux/Datapixx.mex ' PTBDIR 'Psychtoolbox/PsychBasic/Octave3LinuxFiles'], '/', filesep));
+                striplibsfrommexfile([PTBDIR 'Psychtoolbox/PsychBasic/Octave3LinuxFiles/Datapixx.mex']);
             end
         elseif (IsWin)
             system(strrep([DELCMD PTBDIR 'PsychSourceGL/Source/Windows/Base/*.o'], '/', filesep));
-            system(strrep([CPYCMD VPIXXDIR 'VPixx_Software_Tools/DatapixxToolbox_trunk/mexdev/build/octave/win32/Datapixx.mex ' PTBDIR 'Psychtoolbox/PsychBasic/Octave3WindowsFiles'], '/', filesep));
+            system(strrep([CPYCMD VPIXXDIR 'VPixx_Software_Tools/DatapixxToolbox_trunk/mexdev/build/octave/win32/Datapixx.mex ' PTBDIR 'Psychtoolbox/PsychBasic/Octave4WindowsFiles'], '/', filesep));
         end
     else
         if (IsOSX(1))           % 64-bit MATLAB on OS X
