@@ -1,7 +1,7 @@
 function DownloadPsychtoolbox(targetdirectory, flavor, targetRevision)
 % DownloadPsychtoolbox([targetdirectory][, flavor][, targetRevision])
 %
-% This script downloads the latest GNU/Linux, Mac OSX, or Windows
+% This script downloads the latest GNU/Linux, Mac OSX, or MS-Windows
 % Psychtoolbox-3, version 3.0.10 or later, from our git-server to your
 % disk, creating your working copy, ready to use as a new toolbox in your
 % MATLAB/OCTAVE application. Subject to your permission, any old
@@ -9,12 +9,18 @@ function DownloadPsychtoolbox(targetdirectory, flavor, targetRevision)
 % program, checking for all required resources and privileges before it
 % starts.
 %
-% Note: If you use a Debian derives Linux distribution, e.g., Debian or
+% Note: If you use a Debian derived Linux distribution, e.g., Debian or
 % Ubuntu, consider installing the package octave-psychtoolbox-3 or
 % matlab-psychtoolbox-3 instead from http://neuro.debian.net - This is more
-% convenient ans will provide you with automatic updates.
+% convenient and will provide you with automatic updates.
 %
-% CAUTION: Psychtoolbox *will not work* with GNU/Octave on MS-Windows, or
+% CAUTION: Psychtoolbox 3.0.12 will not work anymore with 32-Bit Matlab, or
+% with OSX versions earlier than 10.8 "Mountain Lion". Psychtoolbox may
+% work with versions of Microsoft Windows older than Windows-7, but it is
+% not tested or supported on such ancient Windows systems anymore, so use
+% at your own risk.
+%
+% Psychtoolbox 3.0.11 *will not work* with GNU/Octave on MS-Windows, or
 % with 32-Bit Octave on OSX, as support for these setups has been cancelled
 % for the 3.0.10 series. It will also not work with 32-Bit Matlab on OSX,
 % or with OSX versions earlier than 10.6.8 "Snow Leopard", unless you
@@ -284,11 +290,25 @@ function DownloadPsychtoolbox(targetdirectory, flavor, targetRevision)
 % 07/02/13 mk  Drop support for 32-Bit Matlab on OSX, and thereby for 32-Bit OSX.
 % 07/02/13 mk  Reenable write access for all to Psychtoolbox folder.
 % 07/23/13 mk  Do not prevent execution on 32-Bit Matlab on OSX!
+% 05/18/14 mk  No support for 32-Bit Matlab on Linux and Windows anymore for 3.0.12.
+%              Clarify there's also no support for < OSX 10.8 anymore.
+% 10/04/15 mk  Compatibility fixes for Octave-4, cosmetic cleanups.
+% 10/28/15 mk  32-Bit Octave-4 support for MS-Windows reestablished.
 
 % Flush all MEX files: This is needed at least on M$-Windows for SVN to
 % work if Screen et al. are still loaded.
 clear mex
 
+% Check if this is 32-Bit Matlab on Windows or Linux, which we don't support anymore:
+if (strcmp(computer, 'PCWIN') || strcmp(computer, 'GLNX86')) && (nargin < 2 || isempty(strfind(flavor, 'Psychtoolbox-3.0.')))
+    fprintf('Psychtoolbox 3.0.12 and later do no longer work with 32-Bit versions of Matlab.\n');
+    fprintf('You need to upgrade to a supported 64-Bit version of Octave or Matlab. 32-Bit Octave is still\n');
+    fprintf('supported on GNU/Linux.\n');
+    fprintf('If you must use a legacy 32-Bit Matlab environment, you can call this function\n');
+    fprintf('DownloadPsychtoolbox() with flavor ''Psychtoolbox-3.0.11'', which does support 32-Bit Matlab on Linux and Windows.\n');
+    error('Tried to setup on 32-Bit Matlab, which is no longer supported.');
+end
+
 % Check if this is 32-Bit Octave on OSX, which we don't support anymore:
 if ~isempty(strfind(computer, 'apple-darwin')) && isempty(strfind(computer, '64'))
     fprintf('Psychtoolbox 3.0.11 and later do no longer work with 32-Bit versions of Octave or Matlab on OSX.\n');
@@ -299,10 +319,10 @@ if ~isempty(strfind(computer, 'apple-darwin')) && isempty(strfind(computer, '64'
     error('Tried to setup on 32-Bit Octave, which is no longer supported on OSX.');
 end
 
-% Check if this is Octave on Windows, which we don't support at all:
+% Check if this is Octave-3 on Windows, which we don't support at all:
 if strcmp(computer, 'i686-pc-mingw32')
-    fprintf('Psychtoolbox 3.0.10 and later does no longer work with GNU/Octave on MS-Windows.\n');
-    fprintf('You need to use MacOS/X or GNU/Linux if you want to use Psychtoolbox with Octave.\n');
+    fprintf('Psychtoolbox 3.0.10 and later does no longer work with GNU/Octave-3 on MS-Windows.\n');
+    fprintf('You need to use 32-Bit Octave-4 if you want to use Psychtoolbox with Octave on Windows.\n');
     fprintf('You can also use the alternate download function DownloadLegacyPsychtoolbox() to download\n');
     fprintf('an old legacy copy of Psychtoolbox-3.0.9 which did support 32-Bit Octave 3.2 on Windows.\n');
     error('Tried to setup on Octave, which is no longer supported on MS-Windows.');
@@ -318,7 +338,7 @@ if strcmp(computer,'MAC')
 end
 
 % Check OS
-IsWin = ~isempty(strfind(computer, 'PCWIN')) || strcmp(computer, 'i686-pc-mingw32');
+IsWin = ~isempty(strfind(computer, 'PCWIN')) || strcmp(computer, 'i686-w64-mingw32');
 IsOSX = ~isempty(strfind(computer, 'MAC')) || ~isempty(strfind(computer, 'apple-darwin'));
 IsLinux = strcmp(computer,'GLNX86') || strcmp(computer,'GLNXA64') || ~isempty(strfind(computer, 'linux-gnu'));
 
@@ -337,7 +357,7 @@ end
 
 % Check if this is a Matlab of version prior to V 7.4 aka R2007a:
 v = ver('matlab');
-if ~isempty(v)
+if ~isempty(v) && ~isempty(v(1).Version)
     v = v(1).Version; v = sscanf(v, '%i.%i.%i');
     if (v(1) < 7) || ((v(1) == 7) && (v(2) < 4))
         % Matlab version < 7.4 detected. This is no longer
@@ -482,28 +502,28 @@ else
     % simply have to hope that it is in some system dependent search path.
 
     % Currently, we only know how to check this for Mac OSX.
-	if IsOSX
-		svnpath = '';
-		
-		if isempty(svnpath) && exist('/opt/subversion/bin/svn', 'file')
-			svnpath = '/opt/subversion/bin/';
-		end
+    if IsOSX
+        svnpath = '';
 
-		if isempty(svnpath) && exist('/usr/bin/svn','file')
-			svnpath='/usr/bin/';
-		end
+        if isempty(svnpath) && exist('/opt/subversion/bin/svn', 'file')
+            svnpath = '/opt/subversion/bin/';
+        end
 
-		if isempty(svnpath) && exist('/usr/local/bin/svn','file')
-			svnpath='/usr/local/bin/';
-		end
+        if isempty(svnpath) && exist('/usr/bin/svn','file')
+            svnpath='/usr/bin/';
+        end
 
-		if isempty(svnpath) && exist('/bin/svn','file')
-			svnpath='/bin/';
-		end
+        if isempty(svnpath) && exist('/usr/local/bin/svn','file')
+            svnpath='/usr/local/bin/';
+        end
 
-		if isempty(svnpath) && exist('/opt/local/bin/svn', 'file')
-			svnpath = '/opt/local/bin/';
-		end
+        if isempty(svnpath) && exist('/bin/svn','file')
+            svnpath='/bin/';
+        end
+
+        if isempty(svnpath) && exist('/opt/local/bin/svn', 'file')
+            svnpath = '/opt/local/bin/';
+        end
 
         if isempty(svnpath)
             fprintf('The Subversion client "svn" is not in one of its expected\n');
@@ -513,7 +533,7 @@ else
             fprintf('and then run %s again.\n', mfilename);
             error('Subversion client is missing. Please install it.');
         end
-	end
+    end
 end
 
 if ~isempty(svnpath)
@@ -542,13 +562,13 @@ if err
         % If this works then we're likely on Matlab:
         p=fullfile(matlabroot,'toolbox','local','pathdef.m');
         fprintf(['Sorry, SAVEPATH failed. Probably the pathdef.m file lacks write permission. \n'...
-            'Please ask a user with administrator privileges to enable \n'...
-            'write by everyone for the file:\n\n''%s''\n\n'],p);
+                 'Please ask a user with administrator privileges to enable \n'...
+                 'write by everyone for the file:\n\n''%s''\n\n'],p);
     catch
         % Probably on Octave:
         fprintf(['Sorry, SAVEPATH failed. Probably your ~/.octaverc file lacks write permission. \n'...
-            'Please ask a user with administrator privileges to enable \n'...
-            'write by everyone for that file.\n\n']);
+                 'Please ask a user with administrator privileges to enable \n'...
+                 'write by everyone for that file.\n\n']);
     end
     
     fprintf(['Once "savepath" works (no error message), run ' mfilename ' again.\n']);
@@ -567,7 +587,7 @@ p='Psychtoolbox123test';
 if success
     rmdir(fullfile(targetdirectory,p));
 else
-	fprintf('Write permission test in folder %s failed.\n', targetdirectory);
+    fprintf('Write permission test in folder %s failed.\n', targetdirectory);
     if strcmp(m,'Permission denied')
         if IsOSX
             fprintf([
@@ -742,43 +762,6 @@ else
     [err,result]=dos(checkoutcommand, '-echo');
 end
 
-% MK: Pointless fallbacks disabled, as GitHub only supports https protocol, so a
-% failure of the first try is game over.
-%
-% if err && (downloadmethod < 1)
-%     % Failed! Let's retry it via http protocol. This may work-around overly
-%     % restrictive firewalls or otherwise screwed network proxies:
-%     fprintf('Command "CHECKOUT" failed with error code %d: \n',err);
-%     fprintf('%s\n\n',result);
-%     fprintf('Will retry now by use of alternative http protocol...\n');
-%     checkoutcommand=[svnpath 'svn checkout ' targetRevision ' http://github.com/Psychtoolbox-3/Psychtoolbox-3/' dflavor '/Psychtoolbox/ ' pt];
-%     fprintf('The following alternative CHECKOUT command asks the Subversion client to \ndownload the Psychtoolbox:\n');
-%     fprintf('%s\n\n',checkoutcommand);
-%     if IsOSX || IsLinux
-%         [err]=system(checkoutcommand);
-%         result = 'For reason, see output above.';
-%     else
-%         [err,result]=dos(checkoutcommand, '-echo');
-%     end    
-% end
-% 
-% if err && (downloadmethod > 0)
-%     % Failed! Let's retry it via https protocol. This may work-around overly
-%     % restrictive firewalls or otherwise screwed network proxies:
-%     fprintf('Command "CHECKOUT" failed with error code %d: \n',err);
-%     fprintf('%s\n\n',result);
-%     fprintf('Will retry now by use of alternative https protocol...\n');
-%     checkoutcommand=[svnpath 'svn checkout ' targetRevision ' https://github.com/Psychtoolbox-3/Psychtoolbox-3/' dflavor '/Psychtoolbox/ ' pt];
-%     fprintf('The following alternative CHECKOUT command asks the Subversion client to \ndownload the Psychtoolbox:\n');
-%     fprintf('%s\n\n',checkoutcommand);
-%     if IsOSX || IsLinux
-%         [err]=system(checkoutcommand);
-%         result = 'For reason, see output above.';
-%     else
-%         [err,result]=dos(checkoutcommand, '-echo');
-%     end    
-% end
-
 if err
     fprintf('Sorry, the download command "CHECKOUT" failed with error code %d: \n',err);
     fprintf('%s\n',result);
