@@ -24,9 +24,11 @@ try
     Screen('TextSize',w, 50);
     Screen('TextStyle', w, 1+2);
     Screen('DrawText', w, 'Hello World!', 100, 100, [0, 0, 255, 255]);
+    fprintf('Requested font: %s, got: %s\n', 'Courier New', Screen('TextFont', w));
     Screen('TextFont',w, 'Times');
     Screen('TextSize',w, 30);
     Screen('DrawText', w, 'Hit any key to exit.', 100, 300, [255, 0, 0, 255]);
+    fprintf('Requested font: %s, got: %s\n', 'Times', Screen('TextFont', w));
     Screen('Flip',w);
     KbWait;
     Screen('CloseAll');
