@@ -177,15 +177,23 @@ function HighColorPrecisionDrawingTest(testconfig, maxdepth, testblocks)
 %
 %      This testcase 5 is incomplete and under development!
 %
-%
+% 6  = Test of color precision of text drawing. This only tests to a fixed
+%      precision of 8 bits for 256 levels at the moment, as our the text
+%      renderer doesn't have a higher precision.
 
 % History:
 % 04/20/08  Written (MK).
 % 10/22/10  Refined to account for small differences between GPU's (MK).
+% 06/20/15  Add case 6 for testing 'DrawText' (MK).
+% 10/04/15  Use PsychGPURasterizerOffsets() to compensate for driver flaws (MK).
+% 10/21/15  Fix the fixes for rasterizer offsets, fix Octave-4 warnings, add
+%           hint to new ConserveVRAMSetting to work around OSX 10.11 AMD bugs.
 
 global win;
 
 close all;
+drivername = mfilename;
+maybeSamplerbug = 0;
 
 % Octave's new plotting backend 'fltk' interferes with Screen(),
 % due to internal use of OpenGL. Problem is it changes the
@@ -216,7 +224,7 @@ if maxdepth > 24
 end
 
 if nargin < 3 || isempty(testblocks)
-    testblocks = [1, 2, 3, 4, 5];
+    testblocks = [1, 2, 3, 4, 5, 6];
 end
 fprintf('Executing the following tests: %i.\n', testblocks);
 
@@ -482,6 +490,9 @@ if ismember(3, testblocks)
     % Open window with black background color:
     [win rect] = PsychImaging('OpenWindow', screenid, 0, [0 0 514 514], [], [], [], []);
 
+    % Test GPU output positioning, report trouble:
+    [rpfx, rpfy, rpix, rpiy, vix, viy, vfx, vfy] = PsychGPURasterizerOffsets(win, drivername);
+
     % Set color clamping (and precision) for standard 2D draw commands:
     Screen('ColorRange', win, 1, ColorClamping);
 
@@ -505,24 +516,22 @@ if ismember(3, testblocks)
 
     % DrawDots test: All pixels in a rectangular block in top-left corner,
     % each with a different color:
-    dyOffset = 0;
-    Screen('DrawDots', win, xy, 1, rgbacolors, [0,dyOffset], 0);
+    Screen('DrawDots', win, xy, 1, rgbacolors, [-vfx, -vfy], 0);
     testname = 'DrawDots';
 
     % Evaluate and log:
-    [resstring, minv, maxv, goodbits] = comparePatches(resstring, testname, maxdepth, refpatch, fbrect);
+    [resstring2, minv, maxv, goodbits] = comparePatches('', testname, maxdepth, refpatch, fbrect);
     if goodbits == 0
         fprintf ('DrawDots result is nonsense. Retrying with a slight twist...\n');
-        % resstring = resstring(1:findstr(resstring, 'DrawDots')-1);
-        resstring = '';
         dyOffset = 1;
-        Screen('DrawDots', win, xy, 1, rgbacolors, [0,dyOffset], 0);
+        Screen('DrawDots', win, xy, 1, rgbacolors, [-vfx, -vfy + dyOffset], 0);
         testname = 'DrawDots';
 
         % Evaluate and log:
-        [resstring, minv, maxv, goodbits] = comparePatches(resstring, testname, maxdepth, refpatch, fbrect);
+        [resstring2, minv, maxv, goodbits] = comparePatches('', testname, maxdepth, refpatch, fbrect);
     end
-    
+    resstring = [resstring resstring2];
+
     % Visualize and clear buffer back to zero aka black:
     Screen('Flip', win, 0, 0, 2);
     
@@ -544,21 +553,21 @@ if ismember(3, testblocks)
     % We draw the lines without line-smoothing (=0), as it only works with
     % alpha-blending and we do not want to use alpha-blending in this test
     % block:
-    Screen('DrawLines', win, lxy, 1, cxy, [], 0);
+    Screen('DrawLines', win, lxy, 1, cxy, [-vfx, -vfy], 0);
     testname = 'DrawLines';
 
     % Evaluate and log:
-    [resstring2, minv, maxv, goodbits] = comparePatches(resstring, testname, maxdepth, refpatch, fbrect);
+    [resstring2, minv, maxv, goodbits] = comparePatches('', testname, maxdepth, refpatch, fbrect);
     if goodbits == 0
         fprintf ('DrawLines result is nonsense. Retrying with a slight twist...\n');
-        Screen('DrawLines', win, lxy, 1, cxy, [0,1], 0);
+        Screen('DrawLines', win, lxy, 1, cxy, [-vfx, -vfy + 1], 0);
         testname = 'DrawLines';
 
         % Evaluate and log:
-        [resstring2, minv, maxv, goodbits] = comparePatches(resstring, testname, maxdepth, refpatch, fbrect);
+        [resstring2, minv, maxv, goodbits] = comparePatches('', testname, maxdepth, refpatch, fbrect);
     end
-    resstring = resstring2;
-    
+    resstring = [resstring resstring2];
+
     % Visualize and clear buffer back to zero aka black:
     Screen('Flip', win, 0, 0, 2);
 
@@ -606,13 +615,17 @@ if ismember(3, testblocks)
     end
     
     tex = Screen('MakeTexture', win, teximg, [], [], Textures);
-    Screen('DrawTexture', win, tex, [], fbrect, [], Filters);
+    Screen('DrawTexture', win, tex, [], OffsetRect(fbrect, 0, 0), [], Filters);
     Screen('Close', tex);
     testname = 'DrawTexture';
 
     % Evaluate and log:
     [resstring, minv, maxv, goodbits] = comparePatches(resstring, testname, maxdepth, refpatch, fbrect);
 
+    if goodbits < maxdepth
+        maybeSamplerbug = 1;
+    end
+
     % Visualize and clear buffer back to zero aka black:
     Screen('Flip', win, 0, 0, 2);
     
@@ -643,7 +656,7 @@ if ismember(3, testblocks)
     end
     
     tex = Screen('MakeTexture', win, teximg, [], [], Textures);
-    Screen('DrawTexture', win, tex, [], fbrect, [], Filters, [], [], gammaShader);
+    Screen('DrawTexture', win, tex, [], OffsetRect(fbrect, 0, 0), [], Filters, [], [], gammaShader);
     Screen('Close', tex);
     testname = 'GammaCorrection';
 
@@ -651,6 +664,10 @@ if ismember(3, testblocks)
     gammapatch = refpatch .^ gamma;
     [resstring, minv, maxv, goodbits] = comparePatches(resstring, testname, maxdepth, gammapatch, fbrect);
 
+    if goodbits < 16
+        maybeSamplerbug = 1;
+    end
+
     % Visualize and clear buffer back to zero aka black:
     Screen('Flip', win, 0, 0, 2);
     
@@ -666,6 +683,9 @@ if ismember(4, testblocks)
     % Open window with black background color:
     [win rect] = PsychImaging('OpenWindow', screenid, 0, [0 0 514 514], [], [], [], []);
 
+    % Test GPU output positioning, report trouble:
+    [rpfx, rpfy, rpix, rpiy, vix, viy, vfx, vfy] = PsychGPURasterizerOffsets(win, drivername);
+
     % Set color clamping (and precision) for standard 2D draw commands. In
     % our case here, this affects the precision and clamping of the
     % 'modulateColor' and 'globalAlpha' parameters of 'DrawTexture'
@@ -723,7 +743,7 @@ if ismember(4, testblocks)
         end
 
         % DrawTexture, modulateColor == [mc mc mc 1] modulated:
-        Screen('DrawTexture', win, tex, [], fbrect, [], Filters, [], mc);
+        Screen('DrawTexture', win, tex, [], OffsetRect(fbrect, 0, 0), [], Filters, [], mc);
         
         % While the GPU does its thing, we compute the Matlab reference
         % patch:
@@ -740,7 +760,11 @@ if ismember(4, testblocks)
     end
     
     resstring = [resstring sprintf('%s : Maxdiff.: %1.17f --> Accurate to at least %i bits.\n', testname, max(maxv), mingoodbits)];
-    
+
+    if mingoodbits < 16
+        maybeSamplerbug = 1;
+    end
+
     Screen('Close', tex);
         
     Screen('CloseAll');
@@ -754,6 +778,9 @@ if ismember(5, testblocks)
     % Open window with black background color:
     [win rect] = PsychImaging('OpenWindow', screenid, [0 0 0 0], [0 0 514 514], [], [], [], []);
 
+    % Test GPU output positioning, report trouble:
+    [rpfx, rpfy, rpix, rpiy, vix, viy, vfx, vfy] = PsychGPURasterizerOffsets(win, drivername);
+
     % Set color clamping (and precision) for standard 2D draw commands. In
     % our case here, this affects the precision and clamping of the
     % 'modulateColor' and 'globalAlpha' parameters of 'DrawTexture'
@@ -772,15 +799,15 @@ if ismember(5, testblocks)
 
     % Compute corresponding 'xy' matrix of output positions:
     [outx , outy] = meshgrid(0:2^floor(maxdepth/2)-1, 0:2^floor(maxdepth/2)-1);
-    
+
     % Build 2-row matrix of (x,y) pixel positions:
     xy = [outx(:)' ; outy(:)'];
-        
+
     % Compute color patch:
     colpatch = reshape(rgbacolors(1,:), length(outy), length(outx));
     colpatch = [colpatch , -colpatch];
-    
-    
+
+
     % Readout region of framebuffer:
     fbrect = [0, 0, max(xy(1,:))+1, max(xy(2,:))+1];
 
@@ -793,7 +820,7 @@ if ismember(5, testblocks)
         % values is 0-255 instead of 0.0 - 1.0. Need to rescale:
         teximg = uint8(colpatch * 255);
     end
-    
+
     tex = Screen('MakeTexture', win, teximg, [], [], Textures);
     fbrect = Screen('Rect', tex)
 
@@ -817,7 +844,7 @@ if ismember(5, testblocks)
 
         % DrawTexture, modulateColor == [mc mc mc 1] modulated:
         for odc=1:nroverdraws
-            Screen('DrawTexture', win, tex, [], fbrect, [], Filters, [], [mc mc mc alpha]);
+            Screen('DrawTexture', win, tex, [], OffsetRect(fbrect, 0, 0), [], Filters, [], [mc mc mc alpha]);
         end
         
         % While the GPU does its thing, we compute the Matlab reference
@@ -829,7 +856,7 @@ if ismember(5, testblocks)
             % MK: This is needed for ATI X1600 under Tiger to emulate the known color clamping bug: refpatch = max(0, min(1, (refpatch + colpatch * mc * alpha)));
             refpatch = (refpatch + colpatch * mc * alpha);
         end
-        
+
         testname = 'DrawTexture-modulateColor&Blend1+1';
 
         % Evaluate and log:
@@ -837,22 +864,117 @@ if ismember(5, testblocks)
         mingoodbits = min([mingoodbits, goodbits]);
         
         % Visualize and clear buffer back to zero aka black:
-        Screen('Flip', win, 0, 0, 2);        
+        Screen('Flip', win, 0, 0, 2);
     end
     
     resstring = [resstring sprintf('%s : Maxdiff.: %1.17f --> Accurate to at least %i bits with %i overdraws.\n', testname, max(maxv), mingoodbits, nroverdraws)];
-    
+
+    if mingoodbits < 16
+        maybeSamplerbug = 1;
+    end
+
     Screen('Close', tex);
         
     Screen('CloseAll');
 end % Test 5.
 
+if ismember(6, testblocks)
+    % Test 6: Precision of DrawText.
+    PsychImaging('PrepareConfiguration')
+    PsychImaging('AddTask', 'General', fbdef);
 
+    % Open window with black background color:
+    [win rect] = PsychImaging('OpenWindow', screenid, 0, [0 0 128 128], [], [], [], []);
+
+    % Set color clamping (and precision) for standard 2D draw commands:
+    Screen('ColorRange', win, 1, ColorClamping);
+
+    Screen('Flip', win);
+
+    textmaxdepth = 8;
+    texttestcolors = 1 - linspace(0,1,2^textmaxdepth);
+    drawncolors = zeros(1, length(texttestcolors));
+    i=1;
+
+    Screen('TextSize', win, 128);
+    Screen('TextFont', win, 'Arial');
+
+    for tc = texttestcolors
+        [xm ym buttons] = GetMouse;
+        if buttons(1)
+            break;
+        end
+
+        Screen('DrawText', win, '+', 0, 0, tc);
+        [nbox, bbox] = Screen('TextBounds', win, '+', 0, 0);
+        [patchx, patchy] = RectCenter(bbox);
+
+        % Flip the buffers - We don't sync to retrace to speed things up a
+        % bit. We also don't clear the drawbuffer, as we're overwriting it in
+        % next loop iteration at the same location anyway -- saves some time.
+        % N.B.: Technically we don't need to flip at all, as we're reading from
+        % the 'drawBuffer' anyway which is unaffected by flips.
+        if 1 || mod (i, 1000) == 0
+            % Ok, only do it every 1000th trial to visualize...
+            Screen('Flip', win, 0, 2, 2);
+        end
+
+        % Readback drawbuffer with float precision, only
+        % the red/luminance channel:
+        patch = Screen('GetImage', win, [], 'drawBuffer', 1, 1);
+
+        % Store result: FillRect
+        drawncolors(1,i) = patch(patchy,patchx);
+
+        if mod(i, 1000)==0
+            fprintf('At %i th testvalue of %i...\n', i, 2^textmaxdepth);
+            beep; drawnow;
+        end
+
+        i=i+1;
+    end
+
+    Screen('CloseAll');
+
+    % Test done.
+    primname = {'DrawText'};
+
+    for j=1:size(drawncolors, 1)
+        deltacolors = single(texttestcolors(1:i-1)) - drawncolors(j, 1:i-1);
+        minv = min(abs(deltacolors));
+        maxv = max(abs(deltacolors));
+        goodbits = floor(-(log2(maxv))) - 1;
+        if goodbits < 0
+            goodbits = 0;
+        end
+
+        testname = char(primname{j});
+
+        if goodbits <= textmaxdepth
+            resstring = [resstring sprintf('2D drawing test: %s : Mindiff.: %1.17f, Maxdiff.: %1.17f --> Accurate to %i bits out of max tested bitdepths %i.\n', testname, minv, maxv, goodbits, textmaxdepth)];
+        else
+            resstring = [resstring sprintf('2D drawing test: %s : Mindiff.: %1.17f, Maxdiff.: %1.17f --> Accurate to full tested bitdepth range of %i bits.\n', testname, minv, maxv, textmaxdepth)];
+        end
+
+        plot(deltacolors);
+        drawnow;
+    end
+end % Test 6.
 
 fprintf('\n\nTest summary:\n');
 fprintf('-------------\n\n');
 fprintf('%s\n\n', resstring);
 
+% Check if this is the samplerbug we found on OSX 10.11 El Capitan with AMD gpus:
+if maybeSamplerbug && (Filters > 0) && (ColorClamping == 0)
+    fprintf('The precision of some test results involving texture drawing with bilinear filtering\n');
+    fprintf('enabled and color clamping disabled is suspiciously low. This hints at a graphics driver\n');
+    fprintf('bug or low precision hardware wrt. shader based texture filtering. You may be able to work\n');
+    fprintf('around this issue by using the Screen ConserveVRAMSetting kPsychAssumeGfxCapVCGood. See the help of\n');
+    fprintf('''help ConserveVRAMSettings'' for more info. If you do not need filtered texture drawing, then it\n');
+    fprintf('would be advisable to use the Screen DrawTexture command with a filterMode of 0 on your system.\n\n');
+end
+
 % Restore synctest settings:
 Screen('Preference', 'SkipSyncTests', oldsync);
 Screen('Preference', 'Verbosity', 3);
@@ -875,6 +997,10 @@ function [resstring, minv, maxv, goodbits] = comparePatches(resstring, testname,
         goodbits = 0;
     end
 
+    if isempty(resstring)
+        resstring = '';
+    end
+
     if goodbits <= maxdepth
         resstring = [resstring sprintf('2D drawing test: %s : Mindiff.: %1.17f, Maxdiff.: %1.17f --> Accurate to %i bits out of max tested bitdepths %i.\n', testname, minv, maxv, goodbits, maxdepth)];
     else
