@@ -176,6 +176,13 @@ else
     end
 end
 
+if IsWayland
+    % We need a onscreen window to collect key input on Wayland:
+    w = Screen('OpenWindow', 0, [255 255 0], [0 0 300 300]);
+    DrawFormattedText(w, 'Type in this window', 'center', 'center', [0 0 255]);
+    Screen('Flip', w);
+end
+
 fprintf('hard enough so the microphone can pick up the noise.\n');
 fprintf('This measurement will be repeated 10 times and obvious wrong\n');
 fprintf('measurements discarded. At the end the mean input device latency\n');
@@ -228,8 +235,13 @@ for trial = 1:10
             KbReleaseWait(portString);
 
             % Wait for keypress in a tight loop:
-            while ~KbCheck(portString); end;
-            tKeypress = GetSecs;
+            while 1
+                [pressed, tKeypress] = KbCheck(portString);
+                if pressed
+                    fprintf('--> dM = %f msecs ', 1000 * (GetSecs - tKeypress));
+                    break;
+                end
+            end
         case 1
             [x y b] = GetMouse([], portString);
             while any(b)
@@ -373,6 +385,9 @@ end
 % Close the audio device:
 PsychPortAudio('Close', pahandle);
 
+% Close Screen in case of Wayland:
+sca;
+
 % Done.
 fprintf('\nTest finished. Average delay across valid trials: %f msecs (stddev = %f msecs).\n\n', mean(tdelay), std(tdelay));
 if ~isempty(tdelay2) && submode ~= 2
