@@ -1,12 +1,18 @@
 function PsychHIDTest
 % PsychHIDTest
 %
+% NOTE: This test is mostly useless on current operating systems, a relic of the
+% past days of OSX on PowerPC. Running it will almost always confuse you without
+% providing any meaningful information. Don't bother reporting any bugs or problems
+% with this script to the Psychtoolbox forum.
+%
+%
 % PsychHIDTest exercises the PsychHID mex file. We list all the HID
 % devices. We read from the keyboard and mouse. We flicker the keyboard
 % LEDs.
 %
-% On MS-Windows we only list the HID devices, as mouse and keyboard are
-% not really accessible for PsychHID on MS-Windows.
+% On non OSX we only list the HID devices, as mouse and keyboard are
+% not really accessible for PsychHID on MS-Windows, and dangerous to access on Linux.
 % 
 % NOT RESPONDING? If PsychHID is not responding, e.g. after unplugging and
 % re-plugging the USB connector, try quitting and restarting MATLAB. We
@@ -25,11 +31,12 @@ function PsychHIDTest
 %             http://groups.yahoo.com/group/psychtoolbox/message/3614
 % 5/14/12  mk Cleanup and improve.
 % 7/01/14  mk Skip all but HID device enumeration on Windows.
+% 12/08/15 mk Skip all but HID device enumeration on other than OSX.
 
-fprintf('TestPsychHID\n');
+fprintf('PsychHIDTest\n');
 fprintf('Making a list of all your HID-compliant devices. ...');
 devices=PsychHID('Devices');
-fprintf('\n\nYou have %d HID-compliant devices:\n',length(devices));
+fprintf('\n\nYou have %d low level HID-compliant devices:\n',length(devices));
 for di=1:length(devices)
     d=devices(di);
     s=sprintf('device %d: %s, %s, %s',di,d.usageName,d.manufacturer,d.product);
@@ -59,7 +66,7 @@ switch length(daq)
         fprintf('You have %d USB-1208FS boxes. Each appears as four devices in the table above.\n',length(daq));
 end
 
-if IsWin
+if ~IsOSX
     return;
 end
 
