@@ -57,6 +57,11 @@ function PsychtoolboxPostInstallRoutine(isUpdate, flavor)
 % 07/02/2013 Drop support for 32-Bit Matlab on OSX, and thereby for 32-Bit OSX. (MK)
 % 07/02/2013 Drop support for OSX versions older than 10.6 "Snow Leopard". (MK)
 % 09/12/2013 Setup PsychStartup.m in startup.m for 32-Bit Windows as well. (MK)
+% 05/18/2014 No support for 32-Bit Matlab on Linux and Windows anymore for 3.0.12. (MK)
+% 09/23/2014 No support for OSX 10.7 and earlier anymore. (MK)
+% 10/05/2014 Add some request for donations at the end. (MK)
+% 10/17/2015 Also add call to PsychStartup() to Octave startup for MS-Windows. (MK)
+% 01/27/2016 Use Octave3 folder for mex files for both Octave-3 and Octave-4. (MK)
 
 fprintf('\n\nRunning post-install routine...\n\n');
 
@@ -143,9 +148,9 @@ catch
     fprintf('Info: Failed to remove .svn subfolders from path. Not a big deal...\n');
 end
 
-% Octave on Windows? This is unsupported as of Version 3.0.10.
-if IsWin && IsOctave
-    error('Use of GNU/Octave on MS-Windows with Psychtoolbox 3.0.10 is no longer supported. Aborted.');
+% Octave 64-Bit on Windows? This is unsupported as of Version 3.0.12, October 2015.
+if IsWin(1) && IsOctave
+    warning('Use of GNU/Octave-4 64-Bit on MS-Windows with Psychtoolbox 3.0.12 is not yet officially supported. Some stuff may work, other stuff not so much.');
 end
 
 % 32-Bit Octave or 32-Bit Matlab on OSX? This is unsupported as of Version 3.0.11.
@@ -158,21 +163,43 @@ if IsOSX && ~Is64Bit
     error('Tried to setup on 32-Bit Octave, which is no longer supported on OSX.');
 end
 
+if ~Is64Bit && ~IsOctave
+    fprintf('Psychtoolbox 3.0.12 and later do no longer work with 32-Bit versions of Matlab.\n');
+    fprintf('You need to upgrade to a supported 64-Bit version of Octave or Matlab. 32-Bit Octave is still\n');
+    fprintf('supported on GNU/Linux.\n');
+    fprintf('If you must use a legacy 32-Bit Matlab environment, you can call the function\n');
+    fprintf('DownloadPsychtoolbox() with flavor ''Psychtoolbox-3.0.11'', which does support 32-Bit Matlab on Linux and Windows.\n');
+    error('Tried to setup on 32-Bit Matlab, which is no longer supported.');
+end
+
 % Check if our own startup function is part of the startup file and add it,
 % if it isn't already part of it. Currently we only need this for MS-Windows.
 if IsWin
     % Is it already implanted? Then we ain't nothing to do:
     if ~IsPsychStartupImplantedInStartup
         % Nope. Does a proper file already exist?
-        whereisit = which('startup.m');
+        if IsOctave
+            whereisit = [get_home_directory filesep '.octaverc'];
+            if exist(whereisit, 'file') == 0
+                whereisit = '';
+            end
+        else
+          whereisit = which('startup.m');
+        end
+
         if isempty(whereisit)
             % No: Create our own one.
-            whereisit = [PsychtoolboxRoot 'PsychInitialize' filesep 'startup.m'];
-            fprintf('Creating a startup.m file for Psychtoolbox at %s\n', whereisit);
+            if IsOctave
+                whereisit = [get_home_directory filesep '.octaverc'];
+                fprintf('Creating a .octaverc file for Psychtoolbox at %s\n', whereisit);
+            else
+                whereisit = [PsychtoolboxRoot 'PsychInitialize' filesep 'startup.m'];
+                fprintf('Creating a startup.m file for Psychtoolbox at %s\n', whereisit);
+            end
         else
-            fprintf('Adding PsychStartup() call to Matlab startup.m file for Psychtoolbox at %s\n', whereisit);            
+            fprintf('Adding PsychStartup() call to startup file for Psychtoolbox at %s\n', whereisit);
         end
-        
+
         % whereisit points to the location of the existing or to be created
         % file. Open (or create) it in append mode:
         try
@@ -183,7 +210,7 @@ if IsWin
             fprintf(fd, '\n');
             fclose(fd);
         catch
-            fprintf('WARNING: Failed to update or create startup.m file to add a call to PsychStartup()! Trouble ahead.\n');
+            fprintf('WARNING: Failed to update or create startup file to add a call to PsychStartup()! Trouble ahead.\n');
         end
     end
     
@@ -205,19 +232,19 @@ if IsOSX
         minorver = inf;
     end
     
-    % Is the operating system minor version 'minorver' < 6?
-    if minorver < 6
-        % Yes. This is MacOSX 10.5 or earlier, i.e., older than 10.6
-        % Snow Leopard. PTB will not work on such an old system:
+    % Is the operating system version < 10.8?
+    if minorver < 8
+        % Yes. This is MacOSX 10.7 or earlier, i.e., older than 10.8
+        % Mountain Lion. PTB will not work on such an old system:
         fprintf('\n\n\n\n\n\n\n\n==== WARNING WARNING WARNING WARNING ====\n\n');
         fprintf('Your operating system is Mac OS/X version 10.%i.\n\n', minorver);
         fprintf('This release of Psychtoolbox-3 is not compatible\n');
-        fprintf('to OSX versions older than 10.6 "Snow Leopard".\n');
+        fprintf('to OSX versions older than 10.8 "Mountain Lion".\n');
         fprintf('That means that almost all functionality will not work!\n\n');
-        fprintf('You can either download an older version of Psychtoolbox\n');
+        fprintf('You could download an older version of Psychtoolbox\n');
         fprintf('onto your system to get better results. See our Wiki for help.\n');
         fprintf('Better though, update your operating system to at least version\n');
-        fprintf('10.6.8 "Snow Leopard" or later.\n');
+        fprintf('10.8.5 or later, better the very latest OSX version.\n');
         fprintf('\n\n\n==== WARNING WARNING WARNING WARNING ====\n\n\n');
         fprintf('Press any key on keyboard to try to continue with setup, although\n');
         fprintf('this will likely fail soon and leave you with a dysfunctional toolbox.\n\n');
@@ -284,9 +311,17 @@ if IsOctave
         octavev = sscanf(version, '%i.%i');
         octavemajorv = octavev(1);
         octaveminorv = octavev(2);
-        
-        rdir = [PsychtoolboxRoot 'PsychBasic' filesep 'Octave' num2str(octavemajorv)];
-        
+
+        fprintf('Octave major version %i detected. Will prepend the following folder to your Octave path:\n', octavemajorv);
+
+        % Octave-3 and Octave-4 can share the same mex files in the Octave-3
+        % folder on Linux:
+        if ismember(octavemajorv, [3,4]) && IsLinux
+            rdir = [PsychtoolboxRoot 'PsychBasic' filesep 'Octave3'];
+        else
+            rdir = [PsychtoolboxRoot 'PsychBasic' filesep 'Octave' num2str(octavemajorv)];
+        end
+
         % Add proper OS dependent postfix:
         if IsLinux
             rdir = [rdir 'LinuxFiles'];
@@ -310,7 +345,6 @@ if IsOctave
             rdir = [rdir '64'];
         end
         
-        fprintf('Octave major version %i detected. Will prepend the following folder to your Octave path:\n', octavemajorv);
         fprintf(' %s ...\n', rdir);
         addpath(rdir);
         
@@ -330,17 +364,20 @@ if IsOctave
         fprintf('=====================================================================\n\n');
     end
     
-    if (octavemajorv < 3) || (octavemajorv == 3 && octaveminorv < 2)
+    if (IsWin && (octavemajorv < 4)) || (octavemajorv < 3) || (octavemajorv == 3 && octaveminorv < 2)
         fprintf('\n\n=================================================================================\n');
         fprintf('WARNING: Your version %s of Octave is obsolete. We strongly recommend\n', version);
         if IsLinux
             % On Linux everything >= 3.2 is fine:
             fprintf('WARNING: using the latest stable version of the Octave 3.2.x series or later for use with Psychtoolbox.\n');
+        elseif IsOSX
+            % On OSX we only care about >= 3.8 atm:
+            fprintf('WARNING: using the latest stable version of the Octave 3.8.x series or later for use with Psychtoolbox.\n');
         else
-            % On other OS'es we only care about >= 3.6 atm:
-            fprintf('WARNING: using the latest stable version of the Octave 3.6.x series or later for use with Psychtoolbox.\n');
+            % On Windows we only care about >= 4.0 atm:
+            fprintf('WARNING: using the latest stable version of the Octave 4.0.x series for use with Psychtoolbox.\n');
         end
-        fprintf('WARNING: Stuff may not work at all or only suboptimal with earlier versions and we\n');
+        fprintf('WARNING: Stuff may not work at all or only suboptimal with other versions and we\n');
         fprintf('WARNING: don''t provide any support for such old versions.\n');
         fprintf('\nPress any key to continue with setup.\n');
         fprintf('=================================================================================\n\n');
@@ -364,8 +401,8 @@ if IsOctave
         % Failed! Either screwed setup of path or missing runtime
         % libraries.
         fprintf('ERROR: WaitSecs-MEX does not work, most likely other MEX files will not work either.\n');
-        fprintf('ERROR: One reason might be that your version %s of Octave is incompatible. We recommend\n', version);        
-        fprintf('ERROR: use of the latest stable version of Octave-3 as announced on the www.octave.org website.\n');
+        fprintf('ERROR: One reason might be that your version %s of Octave is incompatible. We recommend\n', version);
+        fprintf('ERROR: use of the latest stable version of Octave-3 or 4 as announced on the www.octave.org website.\n');
         fprintf('ERROR: Another conceivable reason would be missing or incompatible required system libraries on your system.\n\n');
         fprintf('ERROR: After fixing the problem, restart this installation/update routine.\n\n');
         fprintf('\n\nInstallation aborted. Fix the reported problem and retry.\n\n');
@@ -376,9 +413,9 @@ if IsOctave
 end
 
 % Special case handling for different Matlab releases on MS-Windoze:
-if IsWin
+if IsWin && ~IsOctave
     rc = 0; %#ok<NASGU>
-    
+
     if strfind(cd,'system32')
         % the below code fails if the current directory is system32 (e.g.
         % C:\Windows\system32), as it contains dlls like version.dll, which
@@ -478,7 +515,7 @@ try
         fprintf('\n');
         fprintf('For Screen() and OpenGL support:\n\n');
         fprintf('* The OpenGL utility toolkit GLUT: glut, glut-3 or freeglut are typical provider packages in most Linux distributions.\n');
-        fprintf('* GStreamer multimedia framework: At least version 0.10.24 of the core runtime and the gstreamer-base plugins.\n');
+        fprintf('* GStreamer multimedia framework: At least version 1.0.0 of the core runtime and the gstreamer-base plugins.\n');
         fprintf('  For optimal performance use the latest available versions.\n');
         fprintf('  A simple way to get GStreamer at least on Ubuntu Linux is to install the "rhythmbox" or\n');
         fprintf('  "totem" multimedia-players. You may need to install additional packages to play back all\n');
@@ -489,7 +526,7 @@ try
         fprintf('\n\n');
         fprintf('For PsychKinect() (See "help InstallKinect"):\n\n');
         fprintf('* libusb-1.0 USB low-level access library.\n');
-        fprintf('* libfreenect: Kinect driver library.\n');
+        fprintf('* libfreenect-0.5: Kinect driver library version 0.5 or later.\n');
         fprintf('\n');
         fprintf('For PsychHID() support:\n\n');
         fprintf('* libusb-1.0 USB low-level access library.\n');
@@ -613,6 +650,12 @@ fprintf('\n');
 fprintf('Please also familiarize yourself with the demos contained in the PsychDemos subfolder\n');
 fprintf('and its subfolders. They show best practices for many common tasks and are generally\n');
 fprintf('well documented.\n');
+fprintf('\n\n');
+fprintf('If you find this software useful then please consider donating some money \n');
+fprintf('to support its ongoing maintenance and development. See: \n');
+fprintf('\n');
+fprintf('http://psychtoolbox.org/donations \n');
+fprintf('\n');
 
 fprintf('\nEnjoy!\n\n');
 
